# Aggregation and Linkage of Software Records
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/aggregation-and-linkage-of-software-records#overview)
  * [Benefits](https://help.sap.com/docs/leanix/ea/aggregation-and-linkage-of-software-records#benefits)
  * [Synchronization Details](https://help.sap.com/docs/leanix/ea/aggregation-and-linkage-of-software-records#synchronization-details)
  * [Configuring Aggregation and Linkage](https://help.sap.com/docs/leanix/ea/aggregation-and-linkage-of-software-records#configuring-aggregation-and-linkage)
  * [Aggregation Status](https://help.sap.com/docs/leanix/ea/aggregation-and-linkage-of-software-records#aggregation-status)
  * [Synchronization of Fields with the Reference Catalog](https://help.sap.com/docs/leanix/ea/aggregation-and-linkage-of-software-records#synchronization-of-fields-with-the-reference-catalog)
  * [Viewing Aggregated Items](https://help.sap.com/docs/leanix/ea/aggregation-and-linkage-of-software-records#viewing-aggregated-items)


The aggregation and linkage feature allows you to import multiple software records from ServiceNow in an aggregated way while automatically linking consolidated fact sheets to the reference catalog.
